#!/usr/bin/perl
use warnings;
use strict;
use Debian::Debhelper::Dh_Lib;

# dh_runit installs scripts as provided by source package.  It would
# be nice to maintainers to allow them to not worry about executable
# bit.

# systemd is the chosen service monitoring framework for Ubuntu
# and alternative init systems like runit are not supported.
# So neuter dh-runit unless DH_RUNIT_FORCE_ENABLE is set
# (e.g. needed for lintian tests).
if ($ENV{DH_RUNIT_FORCE_ENABLE}) {
    insert_before('dh_fixperms', 'dh_runit');
}

1;
